@@ -811,7 +811,7 @@ func (v *Display) GetEvent() (*Event, error) {
 
 	//The finalizer is not on the glib.Object but on the event.
 	e := &Event{c}
-	runtime.SetFinalizer(e, (*Event).free)
+	runtime.SetFinalizer(e, func(v *Event) { glib.FinalizerStrategy(v.free) })
 	return e, nil
 }
 
@@ -824,7 +824,7 @@ func (v *Display) PeekEvent() (*Event, error) {
 
 	//The finalizer is not on the glib.Object but on the event.
 	e := &Event{c}
-	runtime.SetFinalizer(e, (*Event).free)
+	runtime.SetFinalizer(e, func(v *Event) { glib.FinalizerStrategy(v.free) })
 	return e, nil
 }
 
@@ -1153,9 +1153,6 @@ func (v *Keymap) GetModifierState() uint {
  * GDK Keyval
  */
 
-// TODO:
-// gdk_keyval_name().
-
 // KeyvalFromName() is a wrapper around gdk_keyval_from_name().
 func KeyvalFromName(keyvalName string) uint {
 	str := (*C.gchar)(C.CString(keyvalName))
@@ -1202,6 +1199,11 @@ func UnicodeToKeyval(v rune) uint {
 	return uint(C.gdk_unicode_to_keyval(C.guint32(v)))
 }
 
+// KeyValName is a wrapper around gdk_keyval_name().
+func KeyValName(keyval uint) string {
+	return C.GoString(C.gdk_keyval_name(C.guint(keyval)))
+}
+
 /*
  * GdkDragContext
  */
@@ -1362,6 +1364,91 @@ func (v *EventButton) MotionValRoot() (float64, float64) {
 	return float64(x), float64(y)
 }
 
+/*
+ * GdkEventTouch
+ */
+
+// EventTouch is a representation of GDK's GdkEventTouch
+type EventTouch struct {
+	*Event
+}
+
+func EventTouchNew() *EventTouch {
+	ee := (*C.GdkEvent)(unsafe.Pointer(&C.GdkEventTouch{}))
+	ev := Event{ee}
+	return &EventTouch{&ev}
+}
+
+// EventTouchNewFromEvent returns an EventTouch from an Event.
+//
+// Using widget.Connect() for a key related signal such as
+// "touch-event" results in a *Event being passed as
+// the callback's second argument. The argument is actually a
+// *EventTouch. EventTouchNewFromEvent provides a means of creating
+// an EventTouch from the Event.
+func EventTouchNewFromEvent(event *Event) *EventTouch {
+	ee := (*C.GdkEvent)(unsafe.Pointer(event.native()))
+	ev := Event{ee}
+	return &EventTouch{&ev}
+}
+
+// Native returns a pointer to the underlying GdkEventTouch.
+func (v *EventTouch) Native() uintptr {
+	return uintptr(unsafe.Pointer(v.native()))
+}
+
+func (v *EventTouch) native() *C.GdkEventTouch {
+	return (*C.GdkEventTouch)(unsafe.Pointer(v.Event.native()))
+}
+
+func (v *EventTouch) Type() EventType {
+	c := v.native()._type
+	return EventType(c)
+}
+
+/*TODO GdkWindow *window */
+
+func (v *EventTouch) Time() uint32 {
+	c := v.native().time
+	return uint32(c)
+}
+
+func (v *EventTouch) X() float64 {
+	c := v.native().x
+	return float64(c)
+}
+
+func (v *EventTouch) Y() float64 {
+	c := v.native().y
+	return float64(c)
+}
+
+/*TODO gdouble *axes */
+
+func (v *EventTouch) State() uint {
+	c := v.native().state
+	return uint(c)
+}
+
+/*TODO GdkEventSequence *sequence */
+
+func (v *EventTouch) EmulatingPointer() uint {
+	c := v.native().emulating_pointer
+	return uint(c)
+}
+
+/*TODO GdkDevice *device */
+
+func (v *EventTouch) XRoot() float64 {
+	c := v.native().x_root
+	return float64(c)
+}
+
+func (v *EventTouch) YRoot() float64 {
+	c := v.native().y_root
+	return float64(c)
+}
+
 /*
  * GdkEventKey
  */
@@ -1927,7 +2014,7 @@ func (c *RGBA) Copy() (*RGBA, error) {
 	}
 	obj := wrapRGBA(cRgba)
 
-	runtime.SetFinalizer(obj, (*RGBA).free)
+	runtime.SetFinalizer(obj, func(v *RGBA) { glib.FinalizerStrategy(v.free) })
 	return obj, nil
 }
 
@@ -2420,7 +2507,7 @@ func (v *Window) PixbufGetFromWindow(x, y, w, h int) (*Pixbuf, error) {
 	obj := &glib.Object{glib.ToGObject(unsafe.Pointer(c))}
 	p := &Pixbuf{obj}
 	//obj.Ref()
-	runtime.SetFinalizer(p, func(_ interface{}) { obj.Unref() })
+	runtime.SetFinalizer(p, func(_ interface{}) { glib.FinalizerStrategy(obj.Unref) })
 	return p, nil
 }
 
@@ -2432,10 +2519,15 @@ func (v *Window) GetDevicePosition(d *Device) (*Window, int, int, ModifierType)
 	underneathWindow := C.gdk_window_get_device_position(v.native(), d.native(), &x, &y, &mt)
 	obj := &glib.Object{glib.ToGObject(unsafe.Pointer(underneathWindow))}
 	rw := &Window{obj}
-	runtime.SetFinalizer(rw, func(_ interface{}) { obj.Unref() })
+	runtime.SetFinalizer(rw, func(_ interface{}) { glib.FinalizerStrategy(obj.Unref) })
 	return rw, int(x), int(y), ModifierType(mt)
 }
 
+// SetOverrideRedirect is a wrapper around gdk_window_set_override_redirect().
+func (v *Window) SetOverrideRedirect(overrideRedirect bool) {
+	C.gdk_window_set_override_redirect(v.native(), gbool(overrideRedirect))
+}
+
 func PixbufGetFromSurface(surface *cairo.Surface, src_x, src_y, width, height int) (*Pixbuf, error) {
 	c := C.gdk_pixbuf_get_from_surface((*C.cairo_surface_t)(unsafe.Pointer(surface.Native())), C.gint(src_x), C.gint(src_y), C.gint(width), C.gint(height))
 	if c == nil {
@@ -2445,7 +2537,7 @@ func PixbufGetFromSurface(surface *cairo.Surface, src_x, src_y, width, height in
 	obj := &glib.Object{glib.ToGObject(unsafe.Pointer(c))}
 	p := &Pixbuf{obj}
 	//obj.Ref()
-	runtime.SetFinalizer(p, func(_ interface{}) { obj.Unref() })
+	runtime.SetFinalizer(p, func(_ interface{}) { glib.FinalizerStrategy(obj.Unref) })
 	return p, nil
 }
 
