@@ -494,7 +494,6 @@ const (
 	FORMAT_SIZE_DEFAULT     FormatSizeFlags = C.G_FORMAT_SIZE_DEFAULT
 	FORMAT_SIZE_LONG_FORMAT FormatSizeFlags = C.G_FORMAT_SIZE_LONG_FORMAT
 	FORMAT_SIZE_IEC_UNITS   FormatSizeFlags = C.G_FORMAT_SIZE_IEC_UNITS
-	FORMAT_SIZE_BITS        FormatSizeFlags = C.G_FORMAT_SIZE_BITS
 )
 
 // FormatSizeFull is a wrapper around g_format_size_full().
@@ -588,7 +587,7 @@ func Take(ptr unsafe.Pointer) *Object {
 	}
 
 	obj.RefSink()
-	runtime.SetFinalizer(obj, (*Object).Unref)
+	runtime.SetFinalizer(obj, func(v *Object) { FinalizerStrategy(v.Unref) })
 	return obj
 }
 
@@ -603,7 +602,7 @@ func Take(ptr unsafe.Pointer) *Object {
 // mark as such.
 func AssumeOwnership(ptr unsafe.Pointer) *Object {
 	obj := newObject(ToGObject(ptr))
-	runtime.SetFinalizer(obj, (*Object).Unref)
+	runtime.SetFinalizer(obj, func(v *Object) { FinalizerStrategy(v.Unref) })
 	return obj
 }
 
@@ -858,13 +857,14 @@ func ValueAlloc() (*Value, error) {
 	//We need to double check before unsetting, to prevent:
 	//`g_value_unset: assertion 'G_IS_VALUE (value)' failed`
 	runtime.SetFinalizer(v, func(f *Value) {
+		FinalizerStrategy(func() {
+			if !f.IsValue() {
+				C.g_free(C.gpointer(f.native()))
+				return
+			}
 
-		if !f.IsValue() {
-			C.g_free(C.gpointer(f.native()))
-			return
-		}
-
-		f.unset()
+			f.unset()
+		})
 	})
 
 	return v, nil
@@ -882,7 +882,7 @@ func ValueInit(t Type) (*Value, error) {
 
 	v := &Value{c}
 
-	runtime.SetFinalizer(v, (*Value).unset)
+	runtime.SetFinalizer(v, func(vv *Value) { FinalizerStrategy(vv.unset) })
 	return v, nil
 }
 
@@ -1339,18 +1339,67 @@ type Signal struct {
 	signalId C.guint
 }
 
-func SignalNew(s string) (*Signal, error) {
-	cstr := C.CString(s)
+func SignalNew(signalName string) (*Signal, error) {
+	cstr := C.CString(signalName)
 	defer C.free(unsafe.Pointer(cstr))
 
 	signalId := C._g_signal_new((*C.gchar)(cstr))
 
 	if signalId == 0 {
-		return nil, fmt.Errorf("invalid signal name: %s", s)
+		return nil, fmt.Errorf("invalid signal name: %s", signalName)
 	}
 
 	return &Signal{
-		name:     s,
+		name:     signalName,
+		signalId: signalId,
+	}, nil
+}
+
+// SignalNewV is a wrapper around g_signal_newv().
+//
+// Parameters:
+//   - signalName          : The name for the signal.
+//   - returnType          : The type of return value, or TYPE_NONE for a signal without a return value.
+//   - nParams             : Amount of extra parameters the signal is going to recieve (the object who emits the signal does not count).
+//   - paramsTypes...      : Datatypes of the parameters (amount of elements must match nParams, except when nParams is 0).
+//                           If nParams is 0 then paramsTypes has to be TYPE_NONE.
+//                           If nParams is 1 then paramsTypes has to be different from TYPE_NONE.
+func SignalNewV(
+	signalName string,
+	returnType Type,
+	nParams uint,
+	paramsTypes ...Type,
+) (*Signal, error) {
+	if nParams == 0 {
+		if paramsTypes[0] != TYPE_NONE || len(paramsTypes) != 1 {
+			return nil, fmt.Errorf("invalid Types: the amount of parameters is %d, paramsTypes must be TYPE_NONE", nParams)
+		}
+	} else if nParams == 1 {
+		if paramsTypes[0] == TYPE_NONE || len(paramsTypes) != 1 {
+			return nil, fmt.Errorf("invalid Types: the amount of parameters is %d, paramsTypes must be different from TYPE_NONE", nParams)
+		}
+	} else {
+		if len(paramsTypes) != int(nParams) {
+			return nil, fmt.Errorf("invalid Types: The amount of elements of paramsTypes has to be equal to %d", nParams)
+		}
+	}
+
+	cstr := C.CString(signalName)
+	defer C.free(unsafe.Pointer(cstr))
+
+	var sliceOfGTypes []C.GType
+	for _, paramType := range paramsTypes {
+		sliceOfGTypes = append(sliceOfGTypes, C.gsize(paramType))
+	}
+
+	signalId := C._g_signal_newv((*C.gchar)(cstr), C.gsize(returnType), C.guint(nParams), (*C.GType)(&sliceOfGTypes[0]))
+
+	if signalId == 0 {
+		return nil, fmt.Errorf("invalid signal name: %s", signalName)
+	}
+
+	return &Signal{
+		name:     signalName,
 		signalId: signalId,
 	}, nil
 }
@@ -1409,3 +1458,11 @@ func Local(input string) string {
 
 	return C.GoString(C.localize(cstr))
 }
+
+// MarkupEscapeText will escape the given text
+func MarkupEscapeText(input string) string {
+	cstr := C.CString(input)
+	defer C.free(unsafe.Pointer(cstr))
+
+	return C.GoString(C.g_markup_escape_text(cstr, -1))
+}
